@@ -10,23 +10,22 @@ package Dancer::Plugin::Redis;
 
 # ABSTRACT: easy database connections for Dancer applications
 
+
 use strict;
 use warnings;
-our $VERSION = '0.12';    # VERSION
+our $VERSION = '0.13'; # VERSION
 use Carp;
 use Data::Dumper;
 use Dancer::Plugin;
 use Try::Tiny;
 
-{
-
-    package RedisWithAuthSupport;
+{package RedisWithAuthSupport;
     use strict;
     use warnings;
     use parent 'Redis';
 
     sub new {
-        my ( $class, %param ) = @_;
+        my ($class, %param) = @_;
 
         my $self = $class->SUPER::new(%param);
         $self->{password} = delete $param{password};
@@ -47,7 +46,7 @@ use Try::Tiny;
     sub __auth {
         my $self = shift;
 
-        $self->auth( $self->{password} ) if defined $self->{password};
+        $self->auth($self->{password}) if defined $self->{password};
 
         return;
     }
@@ -63,19 +62,15 @@ register redis => sub {
 
     $_settings ||= plugin_setting;
 
-    my $conf
-        = $name eq '_default'
-        ? $_settings
-        : $_settings->{connections}->{$name};
-    croak "$name is not defined in your redis conf, please check the doc"
-        unless defined $conf;
+    my $conf = $name eq '_default' ? $_settings : $_settings->{connections}->{$name};
+    croak "$name is not defined in your redis conf, please check the doc" unless defined $conf;
 
     return $_handles->{$name} = RedisWithAuthSupport->new(
-        server    => $conf->{server},
-        debug     => $conf->{debug},
-        encoding  => $conf->{encoding},
+        server => $conf->{server},
+        debug => $conf->{debug},
+        encoding => $conf->{encoding},
         reconnect => $conf->{reconnect} // 60,
-        password  => $conf->{password},
+        password => $conf->{password},
     );
 
 };
@@ -84,6 +79,7 @@ register_plugin;
 
 1;
 
+
 =pod
 
 =head1 NAME
@@ -92,7 +88,7 @@ Dancer::Plugin::Redis - easy database connections for Dancer applications
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -155,50 +151,6 @@ CONNECTIONS', then calling the database() keyword with the name of the
 connection as specified in the config file will get you a database handle
 connected with those details.
 
-=head1 CONTRIBUTING
-
-This module is developed on Github at:
-
-L<https://github.com/celogeek/Dancer-Plugin-Redis>
-
-Feel free to fork the repo and submit pull requests!
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-dancer-plugin-database at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dancer-Plugin-Redis>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Dancer::Plugin::Redis
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dancer-Plugin-Redis>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Dancer-Plugin-Redis>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Dancer-Plugin-Redis>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Dancer-Plugin-Redis/>
-
-=back
-
-You can find the author on IRC in the channel C<#dancer> on irc.perl.org.
-
 =head1 SEE ALSO
 
 L<Dancer>
@@ -207,6 +159,15 @@ L<DBI>
 
 L<Redis>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/celogeek/Dancer-Plugin-Redis/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 celogeek <me@celogeek.com>
@@ -220,4 +181,5 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
